Documentation
¶
Index ¶
- func AddDatabaseToZip(zipPath string, dumpData []byte, databaseName string, postgresVersion string) error
- func BackupAll(client *openwebui.Client, outputDir string) error
- func BackupChats(client *openwebui.Client, outputDir string) error
- func BackupFeedbacks(client *openwebui.Client, outputDir string) error
- func BackupFiles(client *openwebui.Client, outputDir string) error
- func BackupGroups(client *openwebui.Client, outputDir string) error
- func BackupKnowledge(client *openwebui.Client, outputDir string) error
- func BackupModels(client *openwebui.Client, outputDir string) error
- func BackupPrompts(client *openwebui.Client, outputDir string) error
- func BackupSelective(client *openwebui.Client, outputFile string, options *SelectiveBackupOptions, ...) error
- func BackupTools(client *openwebui.Client, outputDir string) error
- func BackupUsers(client *openwebui.Client, outputDir string) error
- type ProgressCallback
- type SelectiveBackupOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddDatabaseToZip ¶ added in v0.12.0
func AddDatabaseToZip(zipPath string, dumpData []byte, databaseName string, postgresVersion string) error
AddDatabaseToZip adds database dump and metadata to an existing ZIP file
func BackupChats ¶ added in v0.4.0
BackupChats is the main entry point for backing up all chats
func BackupFeedbacks ¶ added in v0.5.0
BackupFeedbacks is the main entry point for backing up all feedbacks
func BackupFiles ¶ added in v0.3.0
BackupFiles is the main entry point for backing up all standalone files
func BackupGroups ¶ added in v0.5.0
BackupGroups is the main entry point for backing up all groups
func BackupKnowledge ¶
BackupKnowledge is the main entry point for backing up all knowledge bases
func BackupModels ¶ added in v0.2.0
BackupModels is the main entry point for backing up all models
func BackupPrompts ¶ added in v0.3.0
BackupPrompts is the main entry point for backing up all prompts
func BackupSelective ¶ added in v0.4.0
func BackupSelective(client *openwebui.Client, outputFile string, options *SelectiveBackupOptions, progressCallback ProgressCallback) error
BackupSelective performs a selective backup based on the provided options outputFile should be the full path to the output ZIP file progressCallback is an optional callback function for progress updates (can be nil)
func BackupTools ¶ added in v0.3.0
BackupTools is the main entry point for backing up all tools
Types ¶
type ProgressCallback ¶ added in v0.6.0
ProgressCallback is a function that receives progress updates during backup operations